<?php

namespace inter\mysqlStruct;

class Column
{
    private $name;
    private $type;
    private $length;
    private $nullable;
    private $default;
    private $keyType;
    private $comment;

    public function SetName(string $val): self
    {
        $this->name = $val;
        return $this;
    }

    public function GetName(): string
    {
        return $this->name;
    }

    public function SetComment(string $val): self
    {
        $this->comment = $val;
        return $this;
    }

    public function GetComment(): string
    {
        return $this->comment;
    }

    public function SetType(string $val): self
    {
        $this->type = $val;
        return $this;
    }

    public function GetType(): string
    {
        return $this->type;
    }

    public function SetKeyType(string $val): self
    {
        $this->keyType = $val;
        return $this;
    }

    public function GetKeyType(): string
    {
        return $this->keyType;
    }
}
